function obj=subsasgn(obj,ind,data)
% subsasgn - equivalent to Matlab subsasgn but for deflate objects
% 
%CALL
%  obj=subsassgn(obj,ind,data)
%
%INPUT
%  obj: compressed array
%
%  ind: struct array with fields
%         type: '()'
%         subs: cell array with subscript sets
%

%Deal with special cases 
% M_DEFLATE(:)=[];
% M_DEFLATE(:)=scalar
switch numel(data)
    case 0        
        if strcmp(ind.subs,':')   
            %example: M_DEFLATE(:)=[];
            %return an empty matrix
            obj.size=[0 0];
            obj.data=reset(obj.data);
            return
        end
           
        %check for one or more empty indices
        for k=1:length(ind.subs)
            if isempty(ind.subs{k})                
                %example: M_DEFLATE(indx1,[],indx3)=[];
                %no action needed
                return
            end
        end
        M_DEFLATE(indx1)=[];
        error('assignmen M(I)=[] not yet supported');
    case 1
        if strcmp(ind.subs,':')     
            %example: M_DEFLATE(:)=1;
            %Implement efficient way to initialize matrix
            obj.data(:)=data;                 
            return
        end
end

%Note: prod(size(data))>1

[ISCLOSED,rng,OOB,newsz]=isclosedrange(ind,obj.size);
if ISCLOSED
    %deal with special case: first index is ':'
    if OOB
        %OOB implies new object size
        obj.size=newsz;
    end
    obj.data=setclosedrange(obj.data,rng,data);
    return
end

[subscript,OOB] = getSubscript(ind,obj.size);

if OOB
    %OUT OF BOUND ASSIGNMENT
    %     is this a linear index?
    if length(subscript)==1
        %DEAL WITH LINEAR INDEX        
        linIndices      = sub2indVector(obj.size,subscript{:});
        %is obj a matrix (two or more non-singular dimensions)
        if sum(obj.size>1)>1 && max(linIndices)>prod(obj.size)
            %obj is a matrix. M(I)=x is allowed within bounds of matrix.
            error('In an assignment  A(I) = B, a matrix A cannot be resized.');
        end
        %Go to label: CONTINUE FROM ABOVE

        %Object is empty or vector
        %Expand matrix in non singular dimension if existent
        D=find(obj.size>1)
        if ~isempty(D)
            %size [N,1],[1,N],[0,N],...
            %expand in this dimension
            obj.size(D)=max(obj.size(D),max(linIndices));
            %check if any other dimension is zero
            if any(obj.size==0)
                error('In an assignment  A(I) = B, a matrix A cannot be resized.')
            end
            %Go to label: CONTINUE FROM ABOVE
        else
            %size [1,1],[1,0],[0,1], or [0,0]
            %expand in horizontal dimension
            %final dimensions are [1,N]
            obj.size=[1,max(linIndices)];
            %Go to label: CONTINUE FROM ABOVE
        end %endif ~isempty(D)  
    else
        %DEAL WITH NON LINEAR INDEX
        
        %out of bound assignment ==> if out of bound assignment is on any
        %dimension but last, the elements of the array should be re-arranged.
        %For example:
        %     A=[1 2;3 4] ==> 1 3 2 4
        %     a(3,3)=9
        %     A=[1 2 0;3 4 0;0 0 9] ==> 1 3 0 2 4 0 0 0 9

        %Check wether or not the elements of the matrix should be rearranged
        %Find out which dimensions are out of bound
        %If only last dimension is out of bound:
        % - adjust last element of size vector
        % - assign vector values
        %If other dimension is out of bound:
        % - initialize new vector

        %adjust last element of size vector
        sz=obj.size;
        %append sz with ones for missing dimensions
        for k=(length(sz)+1):length(subscript)
            sz(k)=1;
        end
        %append subscript with ones for missing dimensions
        for k=(length(subscript)+1):length(sz)
            subscript{k}=1;
        end
        %sz and subscript are now equal length
        oldSize=sz; %current size
        for k=1:length(subscript)
            %compute new dimension
            newSize(k)=max(max(subscript{k}),sz(k));
        end
        
        if min(find(newSize>oldSize))<length(oldSize)
            %dimension added which is not last ==> rearrange data
            obj=grow(obj,newSize);%<<<<<<<<<size is modified       
            %Go to label: CONTINUE FROM ABOVE
        else
            %last dimension is increased ==> rearranging data not needed
            obj.size=newSize;              
            %Go to label: CONTINUE FROM ABOVE
        end
        %determine linear index
        linIndices      = sub2indVector(obj.size,subscript{:});
    end
else
    linIndices      = sub2indVector(obj.size,subscript{:});
end


%CONTINUE FROM ABOVE
%linIndices: contains linear element index
%data      : contains data to be assigned (numel(data)>0)

%check size (this will also be done in deflatev/subsasgn but we want to
%            control the error message)
if prod(size(data))~=length(linIndices) && numel(data)>1
    error(' In an assignment  A(I) = B, the number of elements in B and I must be the same.');
end
obj.data(linIndices)=data;



    
    
    

