function segment=emptysegment(STOREMODE,value,N)
% emptysegment - initialize segment for deflated vector
% 
% INPUT
%     STOREMODE: storage mode (from obj.storemode)
%                1: uncompressed storage
%                2: compressed storage
%     value    : scalar value to repeat over all elements
%     N        : required number of repetions 
%                For all segments but the last one. N equals
%                obj.segmentSize
% 
% OUTPUT
%     segment
%     +----dat   : compressed or uncompressed data vector (INT8)
%     +----range : [lowest offset,highest offset] (UINT32)
%NOTE: 
%      - for an unitialized segment: segment.range=[]
%      and:
%      - a segment with zero elements is not allowed to exist: segment.range=[0 0] 
%
%      By convention an uninitialized segment contains all zero elements
%
% NOTE (2):
%     segment structures can only be constructed in the following
%     functions:
%     -1- emptysegment
%     -2- storeSegment



if nargin>1
    switch STOREMODE
        case 1 % memory
            segment.dat=repmat(value,N,1);
            segment.range = uint32([1,N]);
        case 2 %compressed
            segment.dat=compress(repmat(value,N,1));
            segment.range = uint32([1,N]);
        case 3 %disk
            error('mode "disk" not implemented yet');
    end
else
    %return empty segment structure with correct fields
    segment.dat   = int8([]); 
    segment.range = uint32([]);
    segment(1)    = [];
end