function requested=importRequested(obj,segIndx,offsets)
% importRequested - get union from existing and requested data from segment.
% Pad with zeros or blanks if needed.
% 
% INPUT
%     obj      : deflated object
%     segIndx  : current segment
%     offsets  : requested elements
% 
% OUTPUT
%     requested: vector with contents of segment
% 
% SEE ALSO
%     importRequested
%     segmentData


%initialize output vector of right size
requested=emptyData(obj,length(offsets));

%segment exists
segment=obj.segment(segIndx);

%check if segment is initialized
if isempty(segment.range)
    %segment has not been initialized
    return
end

%fill elements based on current contents of segment
rawdata=segmentData(obj.storemode,segment,obj.dataclass);

f_ValidOffset=find(offsets>=segment.range(1) & offsets<=segment.range(2));
if isempty(f_ValidOffset)
    return
end

%return data for requested offsets
requested(f_ValidOffset)=rawdata(offsets(f_ValidOffset)-(segment.range(1)-1));



