function [segdata,returnRange]=importUnion(obj,segIndx,firstRequested,lastRequested)
% importUnion - get union from existing and requested data from segment.
% Pad with zeros or blanks if needed.
% 
% INPUT
%     obj      : deflated object
%     segIndx  : current segment
%     firstRequested,lastRequested: requested offset range (INT32)
% 
% OUTPUT
%     segdata: vector with contenst of segment
%     returnRange(1 x 2): returned offset range (INT32)
% 
% SEE ALSO
%     importRequested
%     segmentData

%-1- this will not be the LAST segment, return max(offsets) elements. Pad
%    with zeros if currentlty the segment contains less
%    then obj.segmentSize elements
%-2- this will be the last SEGMENT. There are to options
%    -2.1- the current statement will not grow the array. Return the
%          content of the segment.
%    -2.2- the current statement will grow the array. Return the
%          content of the segment and append empty values

%The fact that this is the highest segment assigned in the current batch
%does not mean that a later segment cannot exist

returnRange=[firstRequested,lastRequested];

%check existence of segment
if length(obj.segment)<segIndx
    %segment does not yet exist ==> return all empty values
    segdata=emptyData(obj,1+lastRequested-firstRequested);
    return
end

%segment exists
segment=obj.segment(segIndx);

%check if segment is initialized
if isempty(segment.range)
    %segment has not been initialized
    segdata=emptyData(obj,1+lastRequested-firstRequested);
    return
end

%Some elements were stored already

%return the union of new and elements stored already 

% returnRange(1) is now based on requested data (firstRequested)
if segment.range(1)>firstRequested
    dat_prepend=emptyData(obj,segment.range(1)-firstRequested);
    %Leave: returnRange(1)=firstRequested;
else    
    dat_prepend=[];
    returnRange(1)=segment.range(1);
end

% returnRange(2) is now based on requested data (lastRequested)
if lastRequested>segment.range(2)
    dat_append=emptyData(obj,lastRequested-segment.range(2));
    %Leave: returnRange(2)=lastRequested
else    
    dat_append=[];
    returnRange(2)=segment.range(2);
end

if ~isempty(dat_prepend)||~isempty(dat_append)
    segdata=[dat_prepend;segmentData(obj.storemode,obj.segment(segIndx),obj.dataclass);dat_append];
else
    segdata=segmentData(obj.storemode,obj.segment(segIndx),obj.dataclass);
end





