function segment=storeSegment(STOREMODE,data,range)
% storeSegment - store segment of deflated vector
%                any segment that contains data should be filled with this
%                function.
% 
% INPUT
%     STOREMODE: storage mode (from obj.storemode)
%         1: uncompressed storage
%         2: compressed storage
%     data: datacontents of this segment
%           For all segments but the last one. data contain obj.segmentSize
%           elements
% 
% OUTPUT
%     segment
%     +----data: compressed or uncompressed data vector
%     +----range: number of elements stored in this segment (INT32)
% 
% NOTES ON STORAGE
%     - Only segments that contain nonempty fields "data" and "range".
%     Hence, if both of these fields are empty it means that this segment
%     containd obj.segmenSize "empty" values (zeros or blanks depending on
%     datatype)
%     - If a segment contains data, the number of elements in de vector
%     "data" and the number "range" must equal obj.segmenSize, unless
%     this is the last segment. For example if an object stores
%     obj.segmenSize+n elements. The first segment stores obj.segmenSize
%     element and the second n elements.
%     - for this reason special care is needed when extending an existing
%     array. The existing last segment might no longer be last after
%     extending the array. Call "makeComplete.m" to make sure the number of
%     elements  is extended to obj.segmenSize
%
% NOTE (2):
%     segment structures can only be constructed in the following
%     functions:
%     -1- emptysegment
%     -2- storeSegment

% Nanne van der Zijpp
% Modelit
% 2005-2006

if isempty(data)
    error('An empty segment can not be stored');
else
    range=uint32(range);%store ranges as doubles
    if (1+range(2)-range(1)) ~= length(data)        
        error('Assertion fails: data and range not consistent');
    end
    switch STOREMODE
        case 1 % memory
            segment.dat     = data;
            segment.range   = range;
        case 2 %compressed
            segment.dat   = compress(data);
            segment.range = range;
        case 3 %disk
            error('mode "disk" not implemented yet');
    end
end