function obj=set(obj,prop,value)
%Return property of object
%WIJZ ZIJPP: external names are not identical to internal names
if ~nargout
    warning('deflatev/set without outputs has no effect of deflatev object')
end
property=getproperty(prop,{'data','class','segmentSize','mode','N'});
switch property
    case 'class'
        %this method has not yet been implemented
        error('The property "class" of this object can not be changed')
    case 'segmentSize'
        %this method has not yet been implemented
		if length(obj.segment)
			error('The property "segmentSize" of a nonempty object can not be changed')
		end
		obj.segmentSize=value;
    case 'mode'
        value=getproperty(value,{'memory', 'compressed', 'disk'});
        newmode    = strmatch(value ,storeModes); %1,2,of 3

        if newmode==obj.storemode
            %no action needed
            return
        end
        %convert the data block by blok
        hwait=waitbar(0,'Change memory mode');
        for k=1:length(obj.segment)            
            waitbar(k/length(obj.segment),hwait);
            %retrieve the data
            segdata=segmentData(obj.storemode,obj.segment(k),obj.dataclass); 
            %store the data with the new storage method
            obj.segment(k)=storeSegment(newmode,segdata,obj.segment(k).range);            
        end
        close(hwait);
        obj.storemode=newmode;
        
    case 'data'
        %overwrite data and dataclass, keep all other properties alike
                
        %clear old data by overwriting them
        obj.segment = emptysegment(obj.storemode);

        if isempty(value)
            % do not change class or call subsasgn
            return
        end
        %check and adapt class from data
        obj.dataclass        = getproperty(class(value),acceptedClasses);        
        
        %set 1 element of vector to force right size
        obj=subsasgn(obj, substruct('()',{numel(value)}),value(end));

        %copy elements to datavector
        obj=subsasgn(obj, substruct('()',{':'}),value(:));
    case 'N'
        if value==numel(obj)
            return
        end
        if value>numel(obj)
            %set 1 element to zero to force right size
            obj=subsasgn(obj, substruct('()',{value}),obj.emptyvalue);
            return
        end
        %retrieve indices of segment that contains N
        segIndx=1+floor((value-1)/obj.segmentSize);
        first= 1+(segIndx-1)*obj.segmentSize;
        
        curdat.rng=first:value;
        curdat.val=subsref(obj, substruct('()',{curdat.rng}));
        
        %Delete this and later segments
        obj.segment(segIndx:end)=[];
        
        %Enter data again (this also sets the new size)
        obj=subsasgn(obj, substruct('()',{curdat.rng}),curdat.val);            
end

