function obj=setclosedrange(obj,rng,data)
% setclosedrange - set data for closed ranges
% 
%CALL
%  obj=setclosedrange(obj,rng,data)
%
%INPUT
%  obj: compressed vector
%  rng(2,N): set of ranges, specified in pairs
%  data: data that need to be assigned
%
%OUTPUT
%  data: data that corresponds to rng
%
%LARGEST MEMORY CLAIM
%    size of datavector that is assigned

%Check size of range: not empty and even number of elements
rng=verifyRange(rng); 
%- empty ranges deleted 
%- adjacent ranges have been merged
%- reshaped to 2 xN matrix

if numel(data)~=sum(diff(rng)+1)
    error('In an assignment  A(I) = B, the number of elements in B and I must be the same')
end
if ~strcmp(class(data),obj.dataclass)
    %WIJZ ZIJPP FEB 2008: no warning consistent with Matlab behavior
    %     warning('datatype %s stored as %s, possible loss of data',class(data),obj.dataclass);
    data=feval(obj.dataclass,data);
end
if size(rng,2)==1
    obj=dealwithRange(obj,rng,data);
else    
    endInx=cumsum(diff(rng)+1);
    strtIndx=[1,1+endInx(1:end-1)];
    for k=1:size(rng,2)
        obj=dealwithRange(obj,rng(:,k),data(strtIndx(k):endInx(k)));
    end
end
    
function obj=dealwithRange(obj,rng,data)
bSize=obj.segmentSize;
%deal with one closed range. This range may span more then 1 block
startBlk = 1+floor((rng(1)-1)/bSize);
endBlk   = 1+floor((rng(2)-1)/bSize);

%first multiple of bSize>startBlk
endAfterStart = startBlk*bSize;
bounds=endAfterStart:bSize:rng(2); %allsegment ends in range
if isempty(bounds)
    bounds=rng(2);
else
    if rng(2)>bounds(end)
        bounds(end+1)=rng(2);
    end
end

START=rng(1);%START: first index to assign
for k=1:length(bounds)
    segmentOffset1=1+rem(START-1,bSize);
    segmentOffset2=1+rem(bounds(k)-1,bSize);
    dataOffset1   =1+START-rng(1);
    dataOffset2   =1+bounds(k)-rng(1);
    segIndx=1+floor((START-1)/bSize);
    if segmentOffset1==1 && segmentOffset2==bSize
        %assign a full segment
        obj.segment(segIndx)=storeSegment(obj.storemode,data(dataOffset1:dataOffset2),[1,bSize]);
    else
        %retrieve current segment and change some of its values
        %RETREIVE SEGMENT DATA PAD NONEXISTING DATA WITH ZEROS
        [segdata,range]=importUnion(obj,segIndx,segmentOffset1,segmentOffset2);
        
        %MODIFY SEGMENT
        segdata((segmentOffset1:segmentOffset2)-(range(1)-1))=data(dataOffset1:dataOffset2);
        
        %STORE SEGMENT
        obj.segment(segIndx)=storeSegment(obj.storemode,segdata,range);    
    end
    START=bounds(k)+1;
end