function B=availableMemory
% availableMemory - return Largest Contiguous Free Memory Blocks
%
% NOTE: 
% This function relies on the Matlab 'feature memstats' command.
% "feature" returns free memory in MB
% In the present content 1 MB is assumed to be a Mebibyte (1024^2 bytes not
% 10^6 bytes)
%
% TESTED WITH:
%     Matlab 6.5.0 interpreted: FAIL (command feature not implemented)
%     Matlab 7.0.1 interpreted: OK
%     Matlab 7.0.1 compiled   : OK
%     Matlab 7.0.4 interpreted: OK
%     Matlab 7.0.4 compiled: 
% 
% EXAMPLE
%     Largest Contiguous Free Blocks:
%          1. [at 20020000]                    945 MB (3b170000)
%          2. [at 6064a000]                    142 MB (08eb6000)
%          3. [at 698ac000]                    102 MB (06674000)
%          4. [at 0b450000]                     75 MB (04bb0000)
%          5. [at 5d577000]                     48 MB (03089000)
%          6. [at 07aa0000]                     46 MB (02ed0000)
%          7. [at 7d1df000]                     37 MB (02511000)
%          8. [at 5b1c8000]                     35 MB (02318000)
%          9. [at 746eb000]                     28 MB (01c45000)
%         10. [at 6ff74000]                     26 MB (01a5c000)
%                                             ======= ==========
%                                             1488 MB (5d06d000)
% 
% >> availableMemory 
% ans =
%    945000000

% after suggestion by : us@neurol.unizh.ch on Matlab Central


z=evalc('feature(''memstats'')');
n=findstr('Free Blocks:',z);
z=z(n:end);
f1=find(']'==z);
f2=findstr('MB',z);
z=z(f1(1)+1:f2(1)-1);
B=sscanf(z,'%d')*1024^2;

