function fname = extensie(fname, ext)
% Verify extension, append extension if needed
% 
% CALL:
%  fname = extensie(fname, ext)
%
% INPUT:
%  fname: string, candidate filename
%  ext  : string, required file extension
%
% OUTPUT:
%  fname: string, filename including extension
% 
% EXAMPLE:
%  fname1 = extensie('donar', 'dia')
%  fname2 = extensie('donar.dia', 'dia')
% 
% APPROACH:
%  controleer de extensie.
%  als deze niet klopt, voeg extensie toe.
% 
% AUTHOR:
%  Nanne van der Zijpp, ModelIT
% 
% See also: fileparts, putfile, getfile

%WIJZ ZIJPP 20121012: use strcmpi and "||"

% ZIJPP 20140310: change behaviour in the following way:
% - only prepend "." to ext if needed (instead of always)
% - if fname already contains an extension always ignore it (instead of
% only ignore if equal tor ext) 
%
%old behaviour: extensie('donar.mat','dia') ==> donar.mat.dia
%new behaviour: extensie('donar.mat','dia') ==> donar.dia
%old behaviour: extensie('donar','.dia') ==> donar..dia
%new behaviour: extensie('donar','.dia') ==> donar.dia

[pth,nm]=fileparts(fname);
if ext(1)~='.'
    ext=['.',ext];
end
%ext now begins with "."
fname=fullfile(pth,[nm,ext]);

% OLD CODE:
% 
% %define extension including "."
% EXT=['.' ext];
% if length(fname)<length(ext)+1 ||...
%       ~strcmpi(fname(end-length(ext):end),EXT)
%   %extension not correct, append extension
%    fname=[fname EXT];
% end
